@@ -115,6 +115,10 @@ dependency "main-cinc-wrapper"
 # dependency "chef-automate-collect"
 
 dependency "cinc-analyze"
+
+# introduced for rexml cleanup - must run after all gems are installed
+dependency "remove-old-gems"
+
 # removes the go language installed at embedded/go
 dependency "go-uninstall"
 
